@@ -20,8 +20,10 @@ use crate::{
 macro_rules! menuitem {
   ( $description:expr, $key:expr, $accel_group:ident, $window_id:expr, $native_menu_item:expr, $tx:ident ) => {{
     let item = GtkMenuItem::with_label($description);
-    let (key, mods) = gtk::accelerator_parse($key);
-    item.add_accelerator("activate", $accel_group, key, mods, AccelFlags::VISIBLE);
+    if !$key.is_empty() {
+      let (key, mods) = gtk::accelerator_parse($key);
+      item.add_accelerator("activate", $accel_group, key, mods, AccelFlags::VISIBLE);
+    }
     item.connect_activate(move |_| {
       if let Err(e) = $tx.send(($window_id, WindowRequest::Menu(($native_menu_item, None)))) {
         log::warn!("Fail to send native menu request: {}", e);
@@ -244,9 +246,19 @@ impl Menu {
         }
         GtkMenuInfo {
           menu_type: GtkMenuType::Native,
-          menu_item: Some(MenuItem::About(s)),
+          menu_item: Some(MenuItem::About(name, app)),
           ..
-        } => Some(GtkMenuItem::with_label(&format!("About {}", s))),
+        } => {
+          let tx_clone = tx.clone();
+          menuitem!(
+            &format!("About {}", name),
+            "",
+            accel_group,
+            window_id,
+            Some(MenuItem::About(name.clone(), app.clone())),
+            tx_clone
+          )
+        }
         GtkMenuInfo {
           menu_type: GtkMenuType::Native,
           menu_item: Some(MenuItem::Hide),
